/* Copyright (c) 2012 Research In Motion Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// The PhotoBomber is a camera application that lets you take photos and then have them
// "bombed" by someone that jumps in, automatically.
//
// We use the Camera control from cascades multimedia, it needs to be initiated from C++
// code before we can use it though. 
import bb.cascades 1.0
import bb.cascades.multimedia 1.0

 
Page {
    // A Container is used to gather visual items together.

    content: Container {
        objectName: "cameraContainer"
        layout: DockLayout {
        }
                
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            
            // This is the camera control that is defined in the cascades multimedia library.
            Camera {
                id: camera1
                objectName: "myCamera"
                             /*   
                onTouch: {
                    if (event.isDown()) {
                        // Take photo
//                        myIndicator.start();                        
                        capturePhoto();
//                        setting.visible = true;
                    }
                }
*/
              // When the camera is opened we want to start the viewfinder
               onCameraOpened:{
//                    timestamp.selectAspectRatio(camera1, 16 / 9);
                    camera1.startViewfinder();
               }
               // There are loads of messages we could listen to here.
               // onPhotoSaved and onShutterFired are taken care of in the C++ code.
               onCameraOpenFailed: {
                    console.log("onCameraOpenFailed signal received with error " + error);
                }
                onViewfinderStartFailed: {
                    console.log("viewfinderStartFailed signal received with error " + error);
                }
                onViewfinderStopFailed: {
                    console.log("viewfinderStopFailed signal received with error " + error);
                }
                onPhotoCaptureFailed: {
                    console.log("photoCaptureFailed signal received with error " + error);
                }
                onPhotoSaveFailed: {
                    console.log("photoSaveFailed signal received with error " + error);
                }
                onPhotoSaved: {
                    timestamp.manipulateCamPhoto(fileName);
                    myIndicator.stop();    
                    camera1.close();	                    
                    
                }
            }
        }

        Container {
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
        
            ActivityIndicator {
                id: myIndicator
                preferredWidth: 200
                preferredHeight: 200
            }
        }
        
        
    }// content Container

	    actions: [


	        ActionItem {
	            title: "Front"
	            ActionBar.placement: ActionBarPlacement.OnBar
	            imageSource: "asset:///images/icon_camera.png"
	            onTriggered: {
                   camera1.close();	                    
                   camera1.open(CameraUnit.Front);
                   
/*
	                if (camera.cameraUnit() == CameraUnit.Rear)
	                {
	                    camera.close();	                    
	                    camera.open(CameraUnit.Front);
	                }
	                else
	                {
	                    camera.close();	                    
	                    camera.open(CameraUnit.Rear);
	                }
*/
	            }

	        },

	        ActionItem {
	            title: "Rear"
	            ActionBar.placement: ActionBarPlacement.OnBar
	            imageSource: "asset:///images/icon_camera.png"
	            onTriggered: {
                   camera1.close();	                    
                   camera1.open(CameraUnit.Rear);

                }
            },
	        
	        ActionItem {
	            title: "Take"
	            ActionBar.placement: ActionBarPlacement.OnBar
	            imageSource: "asset:///images/icon_takepicture.png"
	            onTriggered: {
                      myIndicator.start();                        
                      camera1.capturePhoto();
	            }
	        }
	        
	        ]
/*	
    attachedObjects: [
        ImageSheet {
            id: imageSheet
        }
    ]
    */
}// Page

